pub struct HyperliquidBootstrapProvider { /* private fields */ }Expand description
Bootstrap provider for Hyperliquid market data.
Implementations
Sourceimpl HyperliquidBootstrapProvider
impl HyperliquidBootstrapProvider
pub fn new(config: HyperliquidSourceConfig) -> Self
Sourcepub fn with_stream_state(
config: HyperliquidSourceConfig,
stream_initialized: Arc<RwLock<InitializedEntities>>,
) -> Self
pub fn with_stream_state( config: HyperliquidSourceConfig, stream_initialized: Arc<RwLock<InitializedEntities>>, ) -> Self
Create a bootstrap provider that shares initialized-entity tracking with the streaming layer so that singletons bootstrapped as Inserts are subsequently emitted as Updates (not duplicate Inserts) by the stream.